# coding: utf-8

"""
    Mentortools Notifications Server

    Mentortools service for Notifications

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json



from pydantic import BaseModel, Field, StrictInt, StrictStr

class FCMCredentialsResponse(BaseModel):
    """
    FCMCredentialsResponse
    """
    id: StrictInt = Field(...)
    portal_id: StrictInt = Field(...)
    project_id: StrictStr = Field(...)
    private_key: StrictStr = Field(...)
    client_email: StrictStr = Field(...)
    __properties = ["id", "portal_id", "project_id", "private_key", "client_email"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> FCMCredentialsResponse:
        """Create an instance of FCMCredentialsResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> FCMCredentialsResponse:
        """Create an instance of FCMCredentialsResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return FCMCredentialsResponse.parse_obj(obj)

        _obj = FCMCredentialsResponse.parse_obj({
            "id": obj.get("id"),
            "portal_id": obj.get("portal_id"),
            "project_id": obj.get("project_id"),
            "private_key": obj.get("private_key"),
            "client_email": obj.get("client_email")
        })
        return _obj





# coding: utf-8

"""
    Mentortools Notifications Server

    Mentortools service for Notifications

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from notifications_server_connector.models.wrapped_response_portal_template_override_response import WrappedResponsePortalTemplateOverrideResponse  # noqa: E501

class TestWrappedResponsePortalTemplateOverrideResponse(unittest.TestCase):
    """WrappedResponsePortalTemplateOverrideResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> WrappedResponsePortalTemplateOverrideResponse:
        """Test WrappedResponsePortalTemplateOverrideResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `WrappedResponsePortalTemplateOverrideResponse`
        """
        model = WrappedResponsePortalTemplateOverrideResponse()  # noqa: E501
        if include_optional:
            return WrappedResponsePortalTemplateOverrideResponse(
                done = True,
                result = notifications_server_connector.models.portal_template_override_response.PortalTemplateOverrideResponse(
                    source_type_id = 56, 
                    source_type = notifications_server_connector.models.overridable_source_type_response.OverridableSourceTypeResponse(
                        id = 56, 
                        name = '', 
                        allowed_variables = [
                            ''
                            ], ), 
                    subject = '', 
                    body = '', 
                    is_override = True, 
                    created_at = 56, 
                    updated_at = 56, )
            )
        else:
            return WrappedResponsePortalTemplateOverrideResponse(
                result = notifications_server_connector.models.portal_template_override_response.PortalTemplateOverrideResponse(
                    source_type_id = 56, 
                    source_type = notifications_server_connector.models.overridable_source_type_response.OverridableSourceTypeResponse(
                        id = 56, 
                        name = '', 
                        allowed_variables = [
                            ''
                            ], ), 
                    subject = '', 
                    body = '', 
                    is_override = True, 
                    created_at = 56, 
                    updated_at = 56, ),
        )
        """

    def testWrappedResponsePortalTemplateOverrideResponse(self):
        """Test WrappedResponsePortalTemplateOverrideResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
